=============================
:code:`Trakt['oauth/device']`
=============================

.. automodule:: trakt.interfaces.oauth.device

  .. autoclass:: DeviceOAuthInterface
    :members: code, poll, token
    :undoc-members:
